==> script.module.dandyscrapers-17.10.30.zip: script.module.dandyscrapers/lib/dandyscrapers/scraperplugins/hevc.py <==
import re
import urlresolver
from md_request import open_url
import xbmc
import urllib
from ..scraper import Scraper
from ..common import random_agent,non_func_hosts
User_Agent = 'Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/55.0.2883.87 Safari/537.36'

class hevc(Scraper):
    domains = ['http://hevcbluray.info']
    name = "HevcBluray"
    sources = []

    def __init__(self):
        self.base_link = 'http://hevcbluray.info'
        self.sources = []

    def scrape_movie(self, title, year, imdb, debrid=False):
        try:
            search_id = title.lower()
            movie_url = '%s/search/%s/feed/rss2/' %(self.base_link,search_id.replace(' ','+'))
            #print 'HEVC:::::::::::::::::::::::::::::'+movie_url
            headers = {'User_Agent':random_agent()}
            LINK = open_url(movie_url,headers=headers, timeout=5).content
            
            match = re.compile('<a rel="nofollow" href="(.+?)">(.+?)<',re.DOTALL).findall(LINK)
            uniques=[]
            for item_url ,TITLE in match:
                if not 'http' in item_url:
                    item_url = 'http://'+item_url
                if item_url not in uniques:
                    uniques.append(item_url)
                    if year in TITLE.lower():
                            
                        self.get_source(item_url)
                
            return self.sources
        except Exception, argument:
            return self.sources

    def get_source(self,item_url):
        #print 'SOURCES pass> '+item_url
        try:
            headers = {'User_Agent':random_agent()}
            LINK = open_url(item_url,headers=headers, timeout=5).content
            res = item_url.upper()
            link = LINK.split('<h3 style="text-align: center;">')
            
            uniques = []
            for p in link:
           
                try:
                    final_url = re.compile('<a href="([^"]+)"').findall(p)[0]

                    if '4K' in res:
                        res='4K'
                    elif '3D' in res:
                        res='3D'
                    elif '1080' in res:
                        res='1080p'                   
                    elif '720' in res:
                        res='720p'
                    elif 'HD' in res:
                        res='HD'
                    else:
                        res='SD'
                
                    HOST = final_url.split('//')[1].replace('www.','')
                    HOST = HOST.split('/')[0].split('.')[0].title()
                    if urlresolver.HostedMediaFile(final_url):
                        if final_url not in uniques:
                            uniques.append(final_url)
                            if not non_func_hosts(HOST.lower()):
                                continue 
                            self.sources.append({'source': HOST,'quality': res,'scraper': self.name,'url': final_url,'direct': False})
                except:
                    pass
            return self.sources
        except Exception, argument:
            return self.sources

==> script.module.dandyscrapers-17.11.13.zip: script.module.dandyscrapers/lib/dandyscrapers/scraperplugins/hevc.py <==
import re
import urlresolver
from md_request import open_url
import xbmc
import urllib
from ..scraper import Scraper
from ..common import random_agent,non_func_hosts
User_Agent = 'Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/55.0.2883.87 Safari/537.36'

class hevc(Scraper):
    domains = ['http://hevcbluray.info']
    name = "HevcBluray"
    sources = []

    def __init__(self):
        self.base_link = 'http://hevcbluray.info'
        self.sources = []

    def scrape_movie(self, title, year, imdb, debrid=False):
        try:
            search_id = title.lower()
            movie_url = '%s/search/%s/feed/rss2/' %(self.base_link,search_id.replace(' ','+'))
            #print 'HEVC:::::::::::::::::::::::::::::'+movie_url
            headers = {'User_Agent':random_agent()}
            LINK = open_url(movie_url,headers=headers, timeout=5).content
            
            match = re.compile('<a rel="nofollow" href="(.+?)">(.+?)<',re.DOTALL).findall(LINK)
            uniques=[]
            for item_url ,TITLE in match:
                if not 'http' in item_url:
                    item_url = 'http://'+item_url
                if item_url not in uniques:
                    uniques.append(item_url)
                    if year in TITLE.lower():
                            
                        self.get_source(item_url)
                
            return self.sources
        except Exception, argument:
            return self.sources

    def get_source(self,item_url):
        #print 'SOURCES pass> '+item_url
        try:
            headers = {'User_Agent':random_agent()}
            LINK = open_url(item_url,headers=headers, timeout=5).content
            res = item_url.upper()
            link = LINK.split('Download Links')
            #link = LINK.split('<h3 style="text-align: center;">')
            
            uniques = []
            for p in link:
           
                try:
                    final_url = re.compile('<a href="([^"]+)"').findall(p)[0]

                    if '4K' in res:
                        res='4K'
                    elif '3D' in res:
                        res='3D'
                    elif '1080' in res:
                        res='1080p'                   
                    elif '720' in res:
                        res='720p'
                    elif 'HD' in res:
                        res='HD'
                    else:
                        res='SD'
                    HOST = final_url.split('//')[1].replace('www.','')
                    HOST = HOST.split('/')[0].split('.')[0].title()
                    print 'HEVC >'+final_url
                    if urlresolver.HostedMediaFile(final_url):
                        if final_url not in uniques:
                            uniques.append(final_url)
                            if not non_func_hosts(HOST.lower()):
                                continue 
                            self.sources.append({'source': HOST,'quality': res,'scraper': self.name,'url': final_url,'direct': False})
                except:
                    pass
            return self.sources
        except Exception, argument:
            return self.sources
